-------------------------------------------------------------------------------------------------
-------------------------------------------------------------------------------------------------
-- Recording when the venue has started
-------------------------------------------------------------------------------------------------
local venueStarted = false
local autochefEnabled = isAutochefEnabled()

local currentTutorial = getCurrentTutorial()
local noTutorialActive = currentTutorial == ""

local getNoTutorialActive = function()
    local testTutorial = getCurrentTutorial()
    local noTutorialActive = testTutorial == ""
    return noTutorialActive
end

-------------------------------------------------------------------------------------------------
-- Cococup Dispenser stuff
-------------------------------------------------------------------------------------------------
local chopStation = getStationWithId("JJ_ChopModSlot1")
registerMessageHandler("kStepApplied","JJ_ChopModSlot1",{},
    function()
        local alteredIngredient = chopStation.getFoodItem()
        if not isNullRef(alteredIngredient) then
            local ingredientId = alteredIngredient.getFirstIngredientID()
            if ingredientId == "JJ_Coconut" then
                sendStationMsgWithParamsAndUserData("kActivate", { "LuaRefillCocoCups"}, {})
            end
        end
    end
)

-------------------------------------------------------------------------------------------------
-- Elephant Refill stuff
-------------------------------------------------------------------------------------------------
local elephantAnimating = 0
local queuedRefills = {}
local elephantAnim = getStationWithId("JJ_BoilElephantSlotAnimTop")
local barrelCounter = getStationWithId("JJ_BoilCounter")

-- start the refill, remove the water with the elephant's trunk
local startElephantRefill = function()
    local numberOfEntries = #queuedRefills
    local waterAvailable = barrelCounter.getCurrentValue()

    sendStationMsgWithParamsAndUserData("kActivate", { "LuaNumEntries",numberOfEntries,"LuaElephantCounter",waterAvailable}, {})
    if elephantAnimating < 1 and numberOfEntries > 0 and waterAvailable > 0 then
        elephantAnimating = 1
        sendStationMsgWithParamsAndUserData("kActivate", {"LuaElephantRefillStart"}, {})
    end
end

-- actually refill the slot
local doElephantRefill = function()
    local numberOfEntries = #queuedRefills
    if numberOfEntries > 0 then
        local firstQueuedRefill = queuedRefills[1]
        local refillLabel = "LuaElephantRefill"..firstQueuedRefill
        table.remove(queuedRefills,1)
        sendStationMsgWithParamsAndUserData("kActivate", {refillLabel}, {})
    end
end


-- registerMessageHandler("kEnded","JJ_BoilBarrelTimer",{},
registerMessageHandler("kStationCounterAtMaxValue","JJ_BoilCounter",{},
    function()
        startElephantRefill()
    end
)

for idx=1,2 do
    local boilModSlotName = "JJ_Boil"..idx.."ModSlot"
    local boilModSlot =  getStationWithId(boilModSlotName)
    if boilModSlot.isUnlocked() then
        table.insert(queuedRefills,idx)
        registerMessageHandler("kIngredientOut",boilModSlotName,{},
            function()
                table.insert(queuedRefills,idx)
                sendStationMsgWithParamsAndUserData("kActivate", {"LuaDisableSlot"..idx}, {})
                if elephantAnimating == 0 then
                    startElephantRefill()
                end
            end
        )

        registerMessageHandler("kEnded","JJ_BoilElephantSlotAnimTop",{"fill_"..idx},
            function()
                sendStationMsgWithParamsAndUserData("kActivate", {"LuaEnableSlot"..idx}, {})
                elephantAnimating = 0
                -- startElephantRefill()
                doElephantRefill()
            end
        )
    end
end

registerMessageHandler("kEnded","JJ_BoilElephantSlotAnimTop",{"outro"},
    function()
        doElephantRefill()
    end
)

-------------------------------------------------------------------------------------------------
-- General Setup
-------------------------------------------------------------------------------------------------
registerMessageHandler("kVenueStarted","",{},
    function()
        venueStarted = true
        local noTutorialActive =  getNoTutorialActive()
        if noTutorialActive then
            sendStationMsgWithParamsAndUserData("kActivate", {"LuaInitialFill","TutorialEnded"}, {})
            if autochefEnabled then
                sendStationMsgWithParamsAndUserData("kActivate", {"LuaRefillCococups","NoTutorial"}, {})
            end
        end
    end
)

registerMessageHandler("kTutorialEnded","",{},
    function()
        local noTutorialActive =  getNoTutorialActive()
        if noTutorialActive and venueStarted then
            sendStationMsgWithParamsAndUserData("kActivate", {"LuaInitialFill","TutorialEnded"}, {})
            if autochefEnabled then
                sendStationMsgWithParamsAndUserData("kActivate", {"LuaRefillCococups","TutorialEnded"}, {})
            end
        end
    end
)
