-------------------------------------------------------------------------------------------------
-------------------------------------------------------------------------------------------------
-- Recording when the venue has started
-------------------------------------------------------------------------------------------------
local venueStarted = false
local autochefEnabled = isAutochefEnabled()

local currentTutorial = getCurrentTutorial()
local noTutorialActive = currentTutorial == ""
local venue = getVenueInstance()
local venueSpecific = getVenueInstance().getVenueSpecific()

local isSandwich = false

local getNoTutorialActive = function()
    local testTutorial = getCurrentTutorial()
    local noTutorialActive = testTutorial == ""
    return noTutorialActive
end



-------------------------------------------------------------------------------------------------
-- Start of Balloon station lua
-------------------------------------------------------------------------------------------------
local refillGreen = function()
    local dispenser = getStationWithId("BOB_GreenBalloonDispenser")
    local noFood = tonumber(dispenser.getNumFoodItems()) <= 0
    if noFood and dispenser.getUnlocked() then
        sendStationMsgWithParamsAndUserData("kActivate", {"LuaRefillGreen"},{})
    end
end

local refillOrange = function()
    local dispenser = getStationWithId("BOB_OrangeBalloonDispenser")
    local noFood = tonumber(dispenser.getNumFoodItems()) <= 0
    if noFood and dispenser.getUnlocked() then
        sendStationMsgWithParamsAndUserData("kActivate", {"LuaRefillOrange"},{})
    end
end

if autochefEnabled then
    registerMessageHandler("kTutorialEnded", "", {},
        function()
            if getNoTutorialActive() then
                refillGreen()
                refillOrange()
            end
        end
    )


    local dispenser = getStationWithId("BOB_OrangeBalloonDispenser")
    if dispenser.getUnlocked() then
        if getNoTutorialActive() then
            refillOrange()
        end
        registerMessageHandler("kIngredientOut", "BOB_OrangeBalloonDispenser", {},
            function()
                refillOrange()
            end
        )
    end

    dispenser = getStationWithId("BOB_GreenBalloonDispenser")
    if dispenser.getUnlocked() then
        if getNoTutorialActive() then
            refillGreen()
        end
        registerMessageHandler("kIngredientOut", "BOB_GreenBalloonDispenser", {},
            function()
                refillGreen()
            end
        )
    end
end

-------------------------------------------------------------------------------------------------
-- End of Balloon station lua
-------------------------------------------------------------------------------------------------


-------------------------------------------------------------------------------------------------
-- Start of Sweets stations lua
-------------------------------------------------------------------------------------------------
local stepsArray = {"BOB_Cake","BOB_Cupcake","BOB_IceCream","BOB_Popsicle" }
local stepsToNumArray = {}
local upgradesArray = {}
local sweetStationSlotNodes = {}
local sweetSlotNames = {"Left","Right" }
local dispenserSlots = {}
local dispenserTimers = {}
local dispenserIcons = {}

local sweetsUpgradeable = getStationWithId("SweetsUpgradeable")
local sweetsSlotsCapacity = tonumber(sweetsUpgradeable.getUpgradeSpecificParam("capacity"))

for idx = 1, #sweetSlotNames do
    local slotName = sweetSlotNames[idx]
    local currentSlot = getStationWithId("SweetsDispenser"..slotName)
    local isUnlocked = sweetsSlotsCapacity >= idx
    currentSlot.setUnlocked(isUnlocked)
    table.insert(dispenserSlots,currentSlot)
    local currentTimer = getStationWithId("SweetsDispenser"..slotName.."Timer")
    table.insert(dispenserTimers,currentTimer)
    if not(autochefEnabled) then
        local slotIcon = getStationWithId(slotName.."IconSprite")
        local regularChefAnimation = getStationWithId("ChefTorsoAnim")
        if not(isNullRef(regularChefAnimation)) then
            local animNode = regularChefAnimation.getAnimNode()
            animNode.setAnchorAttachment("anchor_door"..idx, slotIcon)
        end
        slotIcon.setVisible(sweetsSlotsCapacity<idx)
    end
end

local lastSlotUsed = 1
local getSweetsSlot = function()
    local slotIdx = 1
    if sweetsSlotsCapacity>1 then
        local hasFood1 = tonumber(dispenserSlots[1].getNumFoodItems()) > 0
        local hasFood2 = tonumber(dispenserSlots[2].getNumFoodItems()) > 0
        local inUse1 = dispenserTimers[1].inProgress()
        local inUse2 = dispenserTimers[2].inProgress()

        if not(inUse1 or hasFood1) then
            slotIdx = 1
        elseif not(inUse2 or hasFood2) then
            slotIdx = 2
        elseif not(hasFood1) and hasFood2 then
            slotIdx = 1
        elseif not(hasFood2) and hasFood1 then
            slotIdx = 2
        elseif (inUse1 and inUse2) or (hasFood1 and hasFood2) then
            if lastSlotUsed == 1 then
                slotIdx = 2
            end
        end

        lastSlotUsed = slotIdx
    end
    return slotIdx

end

for idx = 1, #stepsArray do

    local step = stepsArray[idx]
    local upgradeable = getStationWithId(step.."Upgradeable")

    registerMessageHandler("kEnded", step.."Anim", { "active" },
        function()

            --if autochefEnabled and getNoTutorialActive() then
            --    local i = 0
            --else
                local freeSlotIdx = getSweetsSlot()
                local currentDispenser = dispenserSlots[freeSlotIdx]
                local currentTimer = dispenserTimers[freeSlotIdx]
                --Don't restart a dispenser that's already making or has this ingredient
                if currentDispenser.getIngredientId() == step and (currentDispenser.getNumFoodItems() > 0 or currentTimer.inProgress()) then
                    local i = 0
                else
                    -- Set the dispenser to produce the correct ingredient
                    currentDispenser.setIngredientId(step)
                    currentTimer.stop("")
        --                    Set the dispenser timer to use this sweet's cooldown time
                    currentTimer.setCooldownTime(upgradeable.getUpgradeSpecificParam("cooldown_time"))
                    currentTimer.resetPanicBoostActive()
                    local side = sweetSlotNames[freeSlotIdx]
                    sendStationMsgWithParamsAndUserData("kActivate", {"LuaSweetIcon"..side,step}, {})
                    sendStationMsgWithParamsAndUserData("kActivate",{side.."DispenserRefill"},{})
                end
            --end
        end
    )

    if not(isNullRef(upgradeable)) then
        upgradesArray[step] = upgradeable

--        if not(isNullRef(upgradeable.getUpgradeSpecificParam("speed_display_level"))) then
--            local i = 0
--        end
    end
end

if not(autochefEnabled) then
    local cookieAnim = getStationWithId("ChefTorsoAnim")
    local cookieAnimNode = cookieAnim.getAnimNode()
    local sweetIcon1 = getStationWithId("LeftIconSprite")
    local sweetIcon2 = getStationWithId("RightIconSprite")
--    cookieAnimNode.setAnchorAttachment("anchor_door1", sweetIcon1)
--    cookieAnimNode.setAnchorAttachment("anchor_door1", sweetIcon2)
end
-------------------------------------------------------------------------------------------------
-- End of Sweets stations lua
-------------------------------------------------------------------------------------------------
registerMessageHandler("kVenueStarted", "", {},
    function()
        venueStarted = true
	isSandwich = (math.random(2) == 1)
    end
)

-------------------------------------------------------------------------------------------------
-- The great hotdog/sandwich debate
-------------------------------------------------------------------------------------------------
registerMessageHandler("kIngredientIn", "BOB_BreadModSlot", {"BOB_HotDog"},
    function()

	chance = math.random(5)
	if chance == 5 then
		if isSandwich then
			sendStationMsgWithParamsAndUserData("kActivate", { "HotDogTip" }, { })
		else
			sendStationMsgWithParamsAndUserData("kActivate", { "SandwichTip" }, { })
		end
	end
    end
)
