-------------------------------------------------------------------------------------------------
-------------------------------------------------------------------------------------------------
-- Recording when the venue has started
-------------------------------------------------------------------------------------------------
local venueStarted = false
local autochefEnabled = isAutochefEnabled()

local currentTutorial = getCurrentTutorial()
local noTutorialActive = currentTutorial == ""

local getNoTutorialActive = function()
    local testTutorial = getCurrentTutorial()
    local noTutorialActive = testTutorial == ""
    return noTutorialActive
end

local venueItem = getVenueInstance()
local flo = venueItem.getFlo()

-------------------------------------------------------------------------------------------------
-- Food anchors for storage
-------------------------------------------------------------------------------------------------
local mixitSupplySlots = {1,2,3,4,5}
local mixitSupplyName = {"PIN_Noodles","PIN_Rice","PIN_CurryMix","PIN_SoupMix"}
local mixitDrenLetter = {"D","R","E","N"}
local mixitSupplyFull = {false,false,false,false}
local mixitSupplySelected = {false,false,false,false}
local mixitFoodNames = {"PIN_Chicken","PIN_Beef","PIN_Shrimp","PIN_Veggies","PIN_Pork"}
local mixitApplySlots = {}

local mixitHasFood = false
local mixitFoodName = ""

local mixitReady = false
local mixitActive = false

--Caching MixIt Apply Stations
for idx = 1,4,1 do
	local mixitApplyName = "PIN_MixItSlot"
	mixitApplyName = mixitApplyName..idx
	mixitApplySlots[idx] = getStationWithId(mixitApplyName)
end

--MixIt Plunger TapArea
registerMessageHandler("kActivate", "PIN_MixItPlungerTapArea", {"tap"},
    function()
        if mixitReady then
            sendStationMsgWithParamsAndUserData("kVenueSpecific", {"mixitready"}, {})
        	--find open slot
        	local openSlot = 0
        	local slotIndx = 0
        	for idx=1,4,1 do
        		local slot = mixitApplySlots[idx]
        		if slot.isAvailable() then
        			openSlot = slot
        			slotIndx = idx
        			break
        		end
        	end
        	
        	--No open slot available, do nothing
        	if openSlot == 0 then
                sendStationMsgWithParamsAndUserData("kVenueSpecific", {"nofreeslots"}, {})
        		return
        	end
        	
        	mixitActive = true
        	
        	--Notify the slot to prepare for capturing the food
        	local slotName = "PIN_MixItSlot"
        	slotName = slotName..slotIndx
        	sendStationMsgWithParamsAndUserData("kVenueSpecific", {"NextToCapture",slotName}, {})
        	
			local modStr = ""
			for idx2=1, #mixitSupplySelected do
				if mixitSupplySelected[idx2] then
					if modStr == "" then
						modStr = mixitSupplyName[idx2]
					else
						modStr = modStr..","
						modStr = modStr..mixitSupplyName[idx2]
					end
				end
			end
			
			modStr = modStr..","
			modStr = modStr.."PIN_MixIt"
				
			openSlot.setStepsFromModString(modStr)

            local launcherStorage = getStationWithId("LauncherStorageSlot1")
	        launcherStorage.removeItem()
	        sendStationMsgWithParamsAndUserData("kActivate", {"LuaMixItUsed"}, {})
	    else -- MixIt !Ready
	    	
	    end
    end
)

--Food being put into mixit combo-er
for idx = 1, #mixitFoodNames do
	local foodName = mixitFoodNames[idx]
	registerMessageHandler("kIngredientIn", "LauncherStorageSlot1", {foodName},
		function()
            if not(getNoTutorialActive()) then
                venueItem.setTutorialCondition("kLuaPrepStepComplete1")
            end
			mixitHasFood = true
			mixitFoodName = foodName
		end
	)
end

--Food being removed from the mixit combo-er
registerMessageHandler("kIngredientOut", "LauncherStorageSlot1", {},
	function()
		mixitReady = false
		sendStationMsgWithParamsAndUserData("kVenueSpecific",{"MixItNotReady"},{})
		
		mixitHasFood = false
		mixitFoodName = ""

		--undo any selections unless it's active, will deselect later
		if not mixitActive then		
			for idx=1, #mixitSupplySelected do
				if mixitSupplySelected[idx] then
					mixitSupplySelected[idx] = false
			
					local staticMsg = "LuaSelectStatic"
					staticMsg = staticMsg..mixitSupplyName[idx]
					sendStationMsgWithParamsAndUserData("kActivate",{staticMsg},{})
				end
			end
		end
	end
)

--MixIt station has completed it's active state
registerMessageHandler("kEnded", "ComboAnchorsBehind", {"active"},
	function()
		mixitActive = false
		
		for idx=1, #mixitSupplySelected do
			if mixitSupplySelected[idx] then
				mixitSupplySelected[idx] = false
		
				--Decrement Counters on toggle supplies
				local ingredientUsedMsg = "LuaMixItUsed"
				ingredientUsedMsg = ingredientUsedMsg..mixitSupplyName[idx]
				sendStationMsgWithParamsAndUserData("kActivate", {ingredientUsedMsg}, {})
		
				--Set deselected state on the toggle
				local staticMsg = "LuaSelectStatic"
				staticMsg = staticMsg..mixitSupplyName[idx]
				sendStationMsgWithParamsAndUserData("kActivate",{staticMsg},{})
			end
		end		
	end
)

--Toggle Slot logic
for idx = 1, #mixitSupplyName do
	local supplyName = mixitSupplyName[idx]
	
	--Toggle TapArea being selected 
	local tapAreaName = supplyName
	tapAreaName = tapAreaName.."TapArea"

    local supplyCounter = getStationWithId(supplyName.."Counter")
	registerMessageHandler("kActivate",tapAreaName,{"visit"},
		function()
            local mixitSupplyCount = supplyCounter.getCurrentValue()
			if mixitHasFood and mixitSupplyCount > 0 and not mixitActive then
			
				mixitSupplySelected[idx] = not mixitSupplySelected[idx]
			
				local modStr = ""
				for idx2=1, #mixitSupplySelected do
					if mixitSupplySelected[idx2] then
						if modStr == "" then
							modStr = mixitSupplyName[idx2]
						else
							modStr = modStr..","
							modStr = modStr..mixitSupplyName[idx2]
						end
					end
				end
				
				
				local firstSlot = mixitApplySlots[1]
				local canCook = firstSlot.couldAcceptIngredientWithStepAndModString(
								mixitFoodName, "PIN_MixIt", modStr )
								
				local msgStr = tapAreaName
				msgStr = msgStr.." - "
				msgStr = msgStr..modStr
				sendStationMsgWithParamsAndUserData("kVenueSpecific",{msgStr},{})
				
				if canCook then
					mixitReady = true;
					sendStationMsgWithParamsAndUserData("kVenueSpecific",{"MixItReady"},{})
					
					for idx2=1, #mixitSupplySelected do
						if mixitSupplySelected[idx2] then
							local selectMsg = "LuaSelectCorrect"
							selectMsg = selectMsg..mixitSupplyName[idx2]
							sendStationMsgWithParamsAndUserData("kActivate",{selectMsg},{})
						else
							local staticMsg = "LuaSelectStatic"
							staticMsg = staticMsg..mixitSupplyName[idx2]
							sendStationMsgWithParamsAndUserData("kActivate",{staticMsg},{})							
						end
					end
				else --Can't Cook
					mixitReady = false;
					sendStationMsgWithParamsAndUserData("kVenueSpecific",{"MixItNotReady"},{})
					
					for idx2=1, #mixitSupplySelected do
						if mixitSupplySelected[idx2] then
							local selectMsg = "LuaSelectIncorrect"
							selectMsg = selectMsg..mixitSupplyName[idx2]
							sendStationMsgWithParamsAndUserData("kActivate",{selectMsg},{})
						else
							local staticMsg = "LuaSelectStatic"
							staticMsg = staticMsg..mixitSupplyName[idx2]
							sendStationMsgWithParamsAndUserData("kActivate",{staticMsg},{})							
						end
					end					
				end
            elseif mixitSupplyCount == 0 then
                sendStationMsgWithParamsAndUserData("kVenueSpecific",{"NoSupplies"},{})
			end
		end
	)
end



--Flipper Logic?
registerMessageHandler("kActivate", "LeftFlipperStarterTapArea", {},
    function()
        if not(getNoTutorialActive()) then
            venueItem.setTutorialCondition("kLuaPrepStepComplete2")
        end
        if isAutochefEnabled() then
            sendStationMsgWithParamsAndUserData("kActivate",{"AutochefHandles"},{})
        end
    end
)

registerMessageHandler("kActivate", "RightFlipperStarterTapArea", {},
    function()
        if not(getNoTutorialActive()) then
                venueItem.setTutorialCondition("kLuaPrepStepComplete3")
        end
        if isAutochefEnabled() then
            sendStationMsgWithParamsAndUserData("kActivate",{"AutochefHandles"},{})
        end
    end
)


if autochefEnabled then
    for idx = 1, #mixitSupplyName do
        local supplyName = mixitSupplyName[idx]
        if idx == 1 then
            registerMessageHandler("kVenueStarted","",{},
                function()
                    sendStationMsgWithParamsAndUserData("kActivate",{"LuaAutochefCounters"..mixitDrenLetter[idx]},{})
                end
            )
        else
            local prevSupplyName = mixitSupplyName[idx-1]
            registerMessageHandler("kEnded",prevSupplyName.."CounterSlotAnim",{"reload"},
                function()
                    sendStationMsgWithParamsAndUserData("kActivate",{"LuaAutochefCounters"..mixitDrenLetter[idx]},{})
                end
            )
        end
    end
end
-------------------------------------------------------------------------------------------------
-- General Setup
-------------------------------------------------------------------------------------------------
registerMessageHandler("kVenueStarted", "", {},
    function()
        venueStarted = true
        --for idx = 1, #mixitSupplyName do
        --    local ingredientName = mixitSupplyName[idx]
        --    local mixitFoodSupplyItem = venueItem.createFoodByIngredientID(ingredientName)
        --    local noodleAnchor = getStationWithId(noodleStepName..idx.."Anchor2")
        --    noodleAnchor.captureFoodItem(noodleFoodItem)
        --end
        if autochefEnabled then
            --for idx = 1, #mixitSupplyName do
                --local supplyName = mixitSupplyName[idx]
                -- local supplyCounterLabel = getStationWithId(supplyName.."CounterLabelNormal")

                -- supplyCounterLabel.setText(mixitDrenLetter[idx],false)
                --sendStationMsgWithParamsAndUserData("kActivate",{"LuaAutochefCounters"..mixitDrenLetter[idx]},{})
            --end
        end
    end
)

registerMessageHandler("kTutorialEnded","",{},
    function()

    end
)
