-------------------------------------------------------------------------------------------------
-------------------------------------------------------------------------------------------------
-- Recording when the venue has started
-------------------------------------------------------------------------------------------------
local venueStarted = false
local autochefEnabled = isAutochefEnabled()

local currentTutorial = getCurrentTutorial()
local noTutorialActive = currentTutorial == ""
local venue = getVenueInstance()
local venueSpecific = getVenueInstance().getVenueSpecific()


local getNoTutorialActive = function()
    local testTutorial = getCurrentTutorial()
    local noTutorialActive = testTutorial == ""
    return noTutorialActive
end

local getNoSnowconeTutorialActive = function()
    local testTutorial = getCurrentTutorial()
    local noTutorialActive = not( testTutorial == "kV30_BlueSnowCone" )
    return noTutorialActive
end


-------------------------------------------------------------------------------------------------
-- Snowball and Snowcone stations
-------------------------------------------------------------------------------------------------
local snowconesUnlocked = false
local yetiThrowActive = false
local snowballCount = 0
local redStep = "DL_Red"
local blueStep = "DL_Blue"
local numToStepMap = {redStep,blueStep}
local stepToNumMap = {}
stepToNumMap[redStep] = 1
stepToNumMap[blueStep] = 2

local activeRails = {}
local modStations = {}
local queuedSnowballs = {}
local queuedThrows = {}
queuedThrows[redStep] = false
queuedThrows[blueStep] = false
local snowBallsInThrow = 0

local caveCapacityAnim = getStationWithId("SnowballCaveAnim")

local updateSnowballStatus = function()
    local capacityLabel = "capacity_"..snowballCount
    if snowballCount == 0 then
        capacityLabel = "empty"
        sendStationMsgWithParamsAndUserData("kActivate", { "LuaSnowBallsEmpty" }, {})
    else
        sendStationMsgWithParamsAndUserData("kActivate", { "LuaSnowBallsCapacity" }, {snowballCount})
    end

    if not(isNullRef(caveCapacityAnim)) then
        caveCapacityAnim.startAnimation({capacityLabel},true)
    end
end

local startRail = function(railName)
    if snowballCount > 0 then
        snowballCount = snowballCount - 1
        activeRails[railName] = true
        sendStationMsgWithParamsAndUserData("kActivate", { railName }, {})
        updateSnowballStatus()
        return true
    else
        return false
    end
end

local makeRailName = function(railNum)
    local railName = "LuaStartSnowRail"..railNum
    return railName
end

local queueRail = function(railNum)
    local railName = makeRailName(railNum)
    if snowballCount > 0 and not(activeRails[idx]) then
        startRail(railName)
    else
        table.insert(queuedSnowballs,railNum)
    end

    local queueCount = #queuedSnowballs
end

local throwSnowBall = function(railNum)
    sendStationMsgWithParamsAndUserData("kActivate", { "LuaStartSnowThrow"..numToStepMap[railNum] }, {})
end

local triggerYetiThrow = function()
    if not(yetiThrowActive) then
        yetiThrowActive = true
        sendStationMsgWithParamsAndUserData("kActivate", { "LuaAnimateYetiActive" }, {})
        if autochefEnabled then
            sendStationMsgWithParamsAndUserData("kActivate", { "LuaAutochefRefillSnow" },{})
        end
    end
end

local triggerThrowForStep = function(stepName)
    local throwNum = stepToNumMap[stepName]
    if queuedThrows[stepName] and snowBallsInThrow > 0 then
        snowBallsInThrow = snowBallsInThrow - 1
        queuedThrows[stepName] = false
        throwSnowBall(throwNum)
    end
end

registerMessageHandler("kActivate","SnowballLeverTapArea",{"visit"},
    function()
        if autochefEnabled then
            if not(getNoSnowconeTutorialActive()) then
                sendStationMsgWithParamsAndUserData("kActivate", { "LuaAnimateLever" }, {})
            end
        else
            sendStationMsgWithParamsAndUserData("kActivate", { "LuaAnimateLever" }, {})
        end
    end
)

for idx = 1,2 do
    local stepName = numToStepMap[idx]
    activeRails[idx] = false
    modStations[idx] = getStationWithId(stepName.."1ModSlot")

    if modStations[idx].isUnlocked() then
        registerMessageHandler("kIngredientOut",stepName.."1ModSlot",{},
            function()
                queueRail(idx)
                queuedThrows[stepName] = true
            end
        )
        local railAnimName = "SnowballRailAnim"..idx
        local railAnim = getStationWithId(railAnimName)
        registerMessageHandler("kEnded",railAnimName,{"active"},
            function()
                activeRails[idx] = false
                railAnim.startAnimation({"static"},false)
                snowBallsInThrow = snowBallsInThrow + 1
                triggerYetiThrow()
            end
        )

        registerMessageHandler("kEnded","SnowballThrowAnim"..stepName,{"active"},
            function()
                local snowballFood = venue.createFoodByIngredientID("DL_Snowball")
                if not isNullRef(snowballFood) then
                    modStations[idx].acceptItem(snowballFood)
                end
            end
        )
    end

end

registerMessageHandler("kEnded","SnowballTimer",{},
    function()
        if not(isNullRef(caveCapacityAnim)) then
            local maxSnowballCapacity = caveCapacityAnim.getStationVal("MAX_CAPACITY")
            if snowballCount == 0 then
                sendStationMsgWithParamsAndUserData("kActivate", { "LuaAnimateYetiIntro" }, {})
            end
            snowballCount = maxSnowballCapacity + 0;
        end
        sendStationMsgWithParamsAndUserData("kActivate", { "LuaSnowballsRefilled" }, {snowballCount})
        updateSnowballStatus()

        --Flush any queued snowballs
        local maxQueuedSnowballs = #queuedSnowballs
        for idx = 1, #queuedSnowballs do
            if maxQueuedSnowballs > 0 and snowballCount > 0 then
                startRail(makeRailName(queuedSnowballs[#queuedSnowballs]))
                table.remove(queuedSnowballs,#queuedSnowballs)
            end
        end
    end
)

registerMessageHandler("kStarted","SnowballSlotAnimYeti",{"active_end"},
    function()
        local blueFirst = venueSpecific.isNextSnowConeBlue()
        yetiThrowActive = false
        --Flush all the queued throws so they line up with the yeti's animation
        if blueFirst then
            triggerThrowForStep(blueStep)
            triggerThrowForStep(redStep)
        else
            triggerThrowForStep(redStep)
            triggerThrowForStep(blueStep)
        end
    end
)

registerMessageHandler("kEnded","SnowballSlotAnimYeti",{"active_end"},
    function()
        if snowballCount > 0 then
            sendStationMsgWithParamsAndUserData("kActivate", { "LuaAnimateYetiBallsLeft" }, {})
        else
            sendStationMsgWithParamsAndUserData("kActivate", { "LuaAnimateYetiLastBall" }, {})
        end
    end
)

registerMessageHandler("kVenueStarted", "", {},
    function()
        venueStarted = true
        for idx = 1,2 do
            if modStations[idx].isUnlocked() then
                queueRail(idx)
                local stepName = numToStepMap[idx]
                snowconesUnlocked = true
                queuedThrows[stepName] = true
            end
        end

        if snowconesUnlocked then
            updateSnowballStatus()
            sendStationMsgWithParamsAndUserData("kActivate", { "LuaSnowConesUnlocked" },{})

            if getNoSnowconeTutorialActive() and autochefEnabled then
                sendStationMsgWithParamsAndUserData("kActivate", { "LuaAutochefRefillSnow" },{})
            end
        else
            sendStationMsgWithParamsAndUserData("kActivate", { "LuaCaveLocked" }, {})
        end
    end
)


